import { Parser, Tree } from "@lezer/common";
import { LezerLanguageServer } from "vertexql";
import { parserAdapterNodeSet, tokenToNodeType } from "./constants";
const DEFAULT_NODE_GROUP_SIZE = 4;
export class ParserAdapter extends Parser {
    constructor() {
        super(...arguments);
        this.languageServer = new LezerLanguageServer();
    }
    getNodeTypeIdForTokenType(index) {
        const tokenType = this.languageServer.getTokenTypeForIndex(index);
        return tokenToNodeType[tokenType].id;
    }
    createBufferFromTokens(tokens) {
        const buffer = [];
        tokens.forEach((token) => {
            const nodeTypeId = this.getNodeTypeIdForTokenType(token.type);
            const startOffset = token.startIndex;
            const endOffset = token.stopIndex + 1;
            buffer.push(nodeTypeId, startOffset, endOffset, DEFAULT_NODE_GROUP_SIZE);
        });
        const documentNodeId = tokenToNodeType.document.id;
        const startOffset = tokens[0].startIndex;
        const endOffest = tokens[tokens.length - 1].stopIndex + 1;
        const documentNodeSize = tokens.length * DEFAULT_NODE_GROUP_SIZE + DEFAULT_NODE_GROUP_SIZE;
        buffer.push(documentNodeId, startOffset, endOffest, documentNodeSize);
        return buffer;
    }
    buildTree(document) {
        const tokens = this.languageServer.getTokenStream(document);
        if (tokens.length < 1) {
            return Tree.build({
                buffer: [
                    tokenToNodeType.document.id,
                    0,
                    document.length,
                    DEFAULT_NODE_GROUP_SIZE,
                ],
                nodeSet: parserAdapterNodeSet,
                topID: tokenToNodeType.document.id,
            });
        }
        const buffer = this.createBufferFromTokens(tokens);
        return Tree.build({
            buffer: buffer,
            nodeSet: parserAdapterNodeSet,
            topID: tokenToNodeType.document.id,
        });
    }
    createParse(input, fragments, ranges) {
        return this.startParse(input, fragments, ranges);
    }
    startParse(input, _0, _1) {
        const document = typeof input === "string" ? input : input.read(0, input.length);
        const tree = this.buildTree(document);
        return {
            stoppedAt: input.length,
            parsedPos: input.length,
            stopAt: (_) => { },
            advance: () => tree,
        };
    }
}
//# sourceMappingURL=ParserAdapter.js.map