import { NodeSet, NodeType } from "@lezer/common";
import { styleTags, tags } from "@lezer/highlight";
import { defineLanguageFacet, languageDataProp } from "@codemirror/language";
const punctuations = "( ) { } : [ ]";
export const tokenToNodeType = {
    document: NodeType.define({
        id: 0,
        name: "document",
        top: true,
        props: [
            [
                languageDataProp,
                defineLanguageFacet({
                    commentTokens: {
                        block: { open: "/*", close: "*/" },
                        line: "//",
                    },
                    closeBrackets: { brackets: ["'"] },
                }),
            ],
        ],
    }),
    name: NodeType.define({ id: 1, name: "name" }),
    asc: NodeType.define({ id: 2, name: "asc" }),
    blockComment: NodeType.define({ id: 3, name: "blockComment" }),
    bool: NodeType.define({ id: 4, name: "bool" }),
    string: NodeType.define({ id: 5, name: "string" }),
    desc: NodeType.define({ id: 6, name: "desc" }),
    float: NodeType.define({ id: 7, name: "float" }),
    integer: NodeType.define({ id: 8, name: "integer" }),
    skip: NodeType.define({ id: 9, name: "skip" }),
    sort: NodeType.define({ id: 10, name: "sort" }),
    lineComment: NodeType.define({ id: 11, name: "lineComment" }),
    take: NodeType.define({ id: 12, name: "take" }),
    whiteSpace: NodeType.define({ id: 13, name: "whiteSpace" }),
    unknown: NodeType.define({ id: 14, name: "unknown" }),
};
export const parserAdapterNodeSet = new NodeSet(Object.values(tokenToNodeType)).extend(styleTags({
    name: tags.name,
    string: tags.string,
    blockComment: tags.comment,
    lineComment: tags.comment,
    integer: tags.integer,
    float: tags.float,
    bool: tags.bool,
    asc: tags.name,
    desc: tags.name,
    sort: tags.name,
    skip: tags.number,
    take: tags.number,
    "( )": tags.paren,
    "{ }": tags.brace,
    ",": tags.separator,
    [punctuations]: tags.punctuation,
}));
//# sourceMappingURL=constants.js.map