import { offsetToPos } from "./helpers";
import { vertexqlLanguage } from './Parser/vertexql';
const AUTOCOMPLETE_CHARS = /^[a-zA-Z0-9_@(]$/;
export const completion = vertexqlLanguage.data.of({
    autocomplete(ctx) {
        const word = ctx.matchBefore(/\w*/);
        if (!word) {
            return null;
        }
        const lastWordChar = word.text.split("").pop();
        if (!AUTOCOMPLETE_CHARS.test(lastWordChar) && !ctx.explicit) {
            return null;
        }
        const val = ctx.state.doc.toString();
        const pos = offsetToPos(ctx.state.doc, ctx.pos);
        const results = [];
        if (results.length === 0) {
            return null;
        }
        return {
            from: word.from,
            options: results.map((item) => {
                return {
                    label: item.label,
                    detail: item.detail || "",
                    info(completionData) {
                        if (opts?.onCompletionInfoRender) {
                            return opts.onCompletionInfoRender(item, ctx, completionData);
                        }
                        if (item.documentation ||
                            (item.isDeprecated && item.deprecationReason)) {
                            const el = document.createElement("div");
                            el.textContent =
                                item.documentation ||
                                    item.deprecationReason ||
                                    "";
                            return el;
                        }
                    },
                };
            }),
        };
    },
});
//# sourceMappingURL=completions.js.map